import * as i0 from '@angular/core';
import { EventEmitter, Component, Optional, Inject, ViewChild, Input, Output, NgModule, SkipSelf } from '@angular/core';
import * as i1 from '@angular/material/dialog';
import { MAT_DIALOG_DATA, MatDialogModule } from '@angular/material/dialog';
import * as i7 from 'ngx-quill';
import { QuillEditorComponent, QuillModule } from 'ngx-quill';
import 'quill-mention';
import Quill from 'quill';
import { ImageDrop } from 'quill-image-drop-module';
import * as i2 from '@cleavelandprice/ngx-lib/active-directory';
import * as i3 from '@angular/common';
import { CommonModule } from '@angular/common';
import * as i4 from '@angular/forms';
import { FormsModule, ReactiveFormsModule } from '@angular/forms';
import * as i5 from '@angular/material/icon';
import { MatIconModule } from '@angular/material/icon';
import * as i6 from '@angular/material/tooltip';
import { MatTooltipModule } from '@angular/material/tooltip';
import { MatButtonModule } from '@angular/material/button';

class Buttons {
    constructor() {
        //#region Font Style
        this.bold = true;
        this.italic = true;
        this.strike = true;
        this.underline = true;
        //#endregion
        //#region Media
        this.link = true;
        this.image = true;
        this.video = true;
        //#endregion
        //#region Block Style
        this.blockquote = true;
        this.codeblock = true;
        //#endregion
        //#region Heading Style
        this.h1 = true;
        this.h2 = true;
        //#endregion
        //#region Color
        this.color = true;
        //#endregion
        //#region List Style
        this.bulleted = true;
        this.ordered = true;
        //#endregion
        //#region Script Style
        this.subScript = true;
        this.superScript = true;
        //#endregion
        //#region Indent Style
        this.increaseIndent = true;
        this.decreaseIndent = true;
        //#endregion
        //#region DropDowns
        this.align = true;
        this.font = true;
        this.fontSize = true;
        this.headingStyle = true;
        //#endregion
        //#region Single Buttons
        this.clean = true;
        this.formula = true;
        this.rtl = true;
        this.editorSize = true;
        //#endregion
    }
}

class Icons {
    constructor() {
        this.maximize = 'open_in_full';
        this.minimize = 'close_fullscreen';
        this.popout = 'open_in_full';
        this.popin = 'done';
    }
}

class Tooltips {
    constructor() {
        //#region Font Style
        this.bold = 'Bold';
        this.italic = 'Italic';
        this.strike = 'Strikethrough';
        this.underline = 'Underline';
        //#endregion
        //#region Media
        this.link = 'Link';
        this.image = 'Insert Image';
        this.video = 'Insert Video';
        //#endregion
        //#region Block Style
        this.blockquote = 'Blockquote';
        this.codeblock = 'Code Block';
        //#endregion
        //#region Heading Style
        this.h1 = 'Heading 1';
        this.h2 = 'Heading 2';
        //#endregion
        //#region Color
        this.color = 'Font / Background Color';
        //#endregion
        //#region List Style
        this.bulleted = 'Bulleted List';
        this.ordered = 'Ordered List';
        //#endregion
        //#region Script Style
        this.subScript = 'Subscript';
        this.superScript = 'Superscript';
        //#endregion
        //#region Indent Style
        this.increaseIndent = 'Increase Indent';
        this.decreaseIndent = 'Decrease Indent';
        //#endregion
        //#region DropDowns
        this.align = 'Align';
        this.font = 'Font';
        this.fontSize = 'Font Size';
        this.headingStyle = 'Heading';
        //#endregion
        //#region Single Buttons
        this.clean = 'Clean';
        this.formula = 'Formula';
        this.rtl = 'Right-To-Left';
        this.maximize = 'Maximize';
        this.minimize = 'Minimize';
        this.popout = 'Popout';
        this.popin = 'Done';
        //#endregion
    }
}

class Config {
    constructor() {
        this.buttons = new Buttons();
        this.tooltips = new Tooltips();
        this.icons = new Icons();
        //#region These can be overriden via @Input()
        this.format = 'html';
        this.height = '50vh';
        this.width = '100vw';
        this.maxHeight = '85vh';
        this.maxWidth = '100vw';
        this.enableTooltips = true;
        this.fullscreen = false;
        this.fullscreenMode = 'popout';
        this.readonly = false;
        //#region Optional Quill modules
        this.imageResizeModule = true;
        this.imageDropModule = true;
        this.mentionModule = true;
        this.syntaxModule = true;
        //#endregion
        //#endregion
        //#region Groups
        this.showBlockStyle = () => this.buttons.blockquote || this.buttons.codeblock;
        this.showFontStyle = () => this.buttons.bold || this.buttons.italic || this.buttons.strike || this.buttons.underline;
        this.showQuickHeadingStyle = () => this.buttons.h1 || this.buttons.h2;
        this.showIndentStyle = () => this.buttons.decreaseIndent || this.buttons.increaseIndent;
        this.showListStyle = () => this.buttons.bulleted || this.buttons.ordered;
        this.showMedia = () => this.buttons.link || this.buttons.image || this.buttons.video;
        this.showScriptStyle = () => this.buttons.subScript || this.buttons.superScript;
        //#endregion
    }
}

class EditorComponent {
    //#endregion
    constructor(data, dialogRef, activeDirectoryService, dialog) {
        this.dialogRef = dialogRef;
        this.activeDirectoryService = activeDirectoryService;
        this.dialog = dialog;
        this.config = new Config();
        //#region These can be passed in as @Input(), or use values from config
        this.format = this.config.format;
        this.height = this.config.height;
        this.width = this.config.width;
        this.maxHeight = this.config.maxHeight;
        this.maxWidth = this.config.maxWidth;
        this.enableTooltips = this.config.enableTooltips;
        this.fullscreen = this.config.fullscreen;
        this.fullscreenMode = this.config.fullscreenMode;
        this.readonly = this.config.readonly;
        //#region Optional Quill modules
        this.imageResizeModule = this.config.imageResizeModule;
        this.imageDropModule = this.config.imageDropModule;
        this.mentionModule = this.config.mentionModule;
        this.syntaxModule = this.config.syntaxModule;
        //#endregion
        //#endregion
        this.fullscreenChanged = new EventEmitter();
        //#region Passthrough events
        this.onBlur = new EventEmitter();
        this.onContentChanged = new EventEmitter();
        this.onEditorChanged = new EventEmitter();
        this.onEditorCreated = new EventEmitter();
        this.onFocus = new EventEmitter();
        this.onSelectionChanged = new EventEmitter();
        if (this.imageDropModule) {
            Quill.register('modules/imageDrop', ImageDrop);
        }
        if (data) {
            this.formGroup = data.formGroup;
            this.controlName = data.controlName;
            this.ngModelValue = data.value;
            this.config = data.config;
            this.placeholder = data.placeholder;
            this.format = data.format;
            this.height = data.height;
            this.width = data.width;
            this.maxHeight = data.maxHeight;
            this.maxWidth = data.maxWidth;
            this.enableTooltips = data.enableTooltips;
            this.fullscreen = data.fullscreen;
            this.fullscreenMode = data.fullscreenMode;
            this.readonly = data.readonly;
            this.users = data.users;
        }
    }
    ngOnInit() {
        if (!this.users) {
            this.activeDirectoryService.getUsers().subscribe(users => this.users = users);
        }
    }
    toggleFullscreen() {
        // Debug
        console.log('fullscreenMode', this.fullscreenMode);
        console.log('fullscreen', this.fullscreen);
        console.log('dialogRef', this.dialogRef);
        if (this.fullscreenMode === 'popout') {
            if (this.fullscreen) {
                console.log('path1'); // Debug
                this.dialogRef.close(this.formGroup ?
                    this.formGroup.get(this.controlName)?.value :
                    this.ngModelValue);
            }
            else {
                console.log('path2'); // Debug
                const data = {
                    formGroup: this.formGroup,
                    controlName: this.controlName,
                    value: this.ngModelValue,
                    config: this.config,
                    placeholder: this.placeholder,
                    format: this.format,
                    height: this.maxHeight,
                    width: '100%',
                    maxHeight: this.maxHeight,
                    maxWidth: '100%',
                    enableTooltips: this.enableTooltips,
                    fullscreen: true,
                    fullscreenMode: this.fullscreenMode,
                    readonly: this.readonly,
                    users: this.users
                };
                this.dialog.open(EditorComponent, {
                    disableClose: true,
                    width: this.maxWidth,
                    height: '90vh',
                    data
                })
                    .afterClosed()
                    .subscribe(value => {
                    this.fullscreen = false;
                    if (this.formGroup) {
                        this.formGroup.get(this.controlName)?.setValue(value);
                    }
                    else {
                        this.ngModelValue = value;
                    }
                });
            }
        }
        this.fullscreen = !this.fullscreen;
        this.fullscreenChanged.emit(this.fullscreen);
    }
    tooltip(val) {
        return this.enableTooltips ? val : '';
    }
    get modules() {
        if (!this.users) {
            return undefined;
        }
        const modules = {};
        if (this.imageResizeModule) {
            modules['imageResize'] = {};
        }
        if (this.imageDropModule) {
            modules['imageDrop'] = true;
        }
        if (this.syntaxModule) {
            modules['syntax'] = true;
        }
        if (this.mentionModule) {
            modules['mention'] = {
                allowedChars: /^[A-Za-z\sÅÄÖåäö]*$/,
                onSelect: (item, insertItem) => {
                    const editor = this.editor.quillEditor;
                    insertItem(item);
                    // necessary because quill-mention triggers changes as 'api' instead of 'user'
                    editor.insertText(editor.getLength() - 1, '', 'user');
                },
                source: (searchTerm, renderList) => {
                    if (searchTerm.length === 0) {
                        renderList(this.users?.map(u => ({ value: `${u.displayName} (${u.sAMAccountName.toLowerCase()})` })), searchTerm);
                    }
                    else {
                        const matches = [];
                        this.users.forEach((entry) => {
                            if (entry.displayName.toLowerCase().indexOf(searchTerm.toLowerCase()) !== -1 ||
                                entry.sAMAccountName.toLowerCase().indexOf(searchTerm.toLowerCase()) !== -1) {
                                matches.push({ value: `${entry.displayName} (${entry.sAMAccountName.toLowerCase()})` });
                            }
                        });
                        renderList(matches, searchTerm);
                    }
                }
            };
        }
        return modules;
    }
}
EditorComponent.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "14.2.1", ngImport: i0, type: EditorComponent, deps: [{ token: MAT_DIALOG_DATA, optional: true }, { token: i1.MatDialogRef, optional: true }, { token: i2.ActiveDirectoryService }, { token: i1.MatDialog }], target: i0.ɵɵFactoryTarget.Component });
EditorComponent.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "14.0.0", version: "14.2.1", type: EditorComponent, selector: "cpquill-editor", inputs: { formGroup: "formGroup", controlName: "controlName", ngModelValue: "ngModelValue", config: "config", placeholder: "placeholder", users: "users", format: "format", height: "height", width: "width", maxHeight: "maxHeight", maxWidth: "maxWidth", enableTooltips: "enableTooltips", fullscreen: "fullscreen", fullscreenMode: "fullscreenMode", readonly: "readonly", imageResizeModule: "imageResizeModule", imageDropModule: "imageDropModule", mentionModule: "mentionModule", syntaxModule: "syntaxModule" }, outputs: { fullscreenChanged: "fullscreenChanged", onBlur: "onBlur", onContentChanged: "onContentChanged", onEditorChanged: "onEditorChanged", onEditorCreated: "onEditorCreated", onFocus: "onFocus", onSelectionChanged: "onSelectionChanged" }, viewQueries: [{ propertyName: "editor", first: true, predicate: QuillEditorComponent, descendants: true }], ngImport: i0, template: "<ng-container *ngIf=\"users\">\n    <!-- Reactive forms -->\n    <form *ngIf=\"formGroup\" [formGroup]=\"formGroup\">\n        <quill-editor\n            [formControlName]=\"controlName\"\n            [placeholder]=\"placeholder\"\n            [format]=\"format\"\n            [style.height]=\"fullscreen ? maxHeight : height\"\n            [style.width]=\"fullscreen ? maxWidth : width\"\n            [readOnly]=\"readonly\"\n            [class.readonly]=\"readonly\"\n            [modules]=\"modules\"\n    \n            (onBlur)=\"onBlur.emit($event)\"\n            (onContentChanged)=\"onContentChanged.emit($event)\"\n            (onEditorChanged)=\"onEditorChanged.emit($event)\"\n            (onEditorCreated)=\"onEditorCreated.emit()\"\n            (onFocus)=\"onFocus.emit($event)\"\n            (onSelectionChanged)=\"onSelectionChanged.emit($event)\">\n    \n            <div quill-editor-toolbar>\n                <ng-container [ngTemplateOutlet]=\"toolbar\"></ng-container>\n                <ng-container [ngTemplateOutlet]=\"editorSize\"></ng-container>\n            </div>\n        </quill-editor>\n    </form>\n    \n    <!-- NgModel forms -->\n    <form *ngIf=\"!formGroup\">\n        <quill-editor name=\"editor\"\n            [(ngModel)]=\"ngModelValue\"\n            [placeholder]=\"placeholder\"\n            [format]=\"format\"\n            [style.height]=\"fullscreen ? maxHeight : height\"\n            [style.width]=\"fullscreen ? maxWidth : width\"\n            [readOnly]=\"readonly\"\n            [class.readonly]=\"readonly\"\n            [modules]=\"modules\"\n    \n            (onBlur)=\"onBlur.emit($event)\"\n            (onContentChanged)=\"onContentChanged.emit($event)\"\n            (onEditorChanged)=\"onEditorChanged.emit($event)\"\n            (onEditorCreated)=\"onEditorCreated.emit()\"\n            (onFocus)=\"onFocus.emit($event)\"\n            (onSelectionChanged)=\"onSelectionChanged.emit($event)\">\n    \n            <div quill-editor-toolbar>\n                <ng-container [ngTemplateOutlet]=\"toolbar\"></ng-container>\n                <ng-container [ngTemplateOutlet]=\"editorSize\"></ng-container>\n            </div>\n        </quill-editor>\n    </form>\n</ng-container>\n\n<ng-template #toolbar>\n    <div>\n        <ng-container [ngTemplateOutlet]=\"fontStyle\"></ng-container>\n        <ng-container [ngTemplateOutlet]=\"blockStyle\"></ng-container>\n        <ng-container [ngTemplateOutlet]=\"headingStyle\"></ng-container>\n        <ng-container [ngTemplateOutlet]=\"listStyle\"></ng-container>\n        <ng-container [ngTemplateOutlet]=\"scriptStyle\"></ng-container>\n        <ng-container [ngTemplateOutlet]=\"indentStyle\"></ng-container>\n        <ng-container [ngTemplateOutlet]=\"rtl\"></ng-container>\n        <ng-container [ngTemplateOutlet]=\"fontSize\"></ng-container>\n        <ng-container [ngTemplateOutlet]=\"heading\"></ng-container>\n        <ng-container [ngTemplateOutlet]=\"color\"></ng-container>\n        <ng-container [ngTemplateOutlet]=\"font\"></ng-container>\n        <ng-container [ngTemplateOutlet]=\"align\"></ng-container>\n        <ng-container [ngTemplateOutlet]=\"clean\"></ng-container>\n        <nt-container [ngTemplateOutlet]=\"formula\"></nt-container>\n        <ng-container [ngTemplateOutlet]=\"media\"></ng-container>\n    </div>\n</ng-template>\n\n<ng-template #fontStyle>\n    <span class=\"ql-formats\" *ngIf=\"config.showFontStyle\">\n        <button class=\"ql-bold\"      *ngIf=\"config.buttons.bold\"      [matTooltip]=\"tooltip(config.tooltips.bold)\"></button>\n        <button class=\"ql-italic\"    *ngIf=\"config.buttons.italic\"    [matTooltip]=\"tooltip(config.tooltips.italic)\"></button>\n        <button class=\"ql-underline\" *ngIf=\"config.buttons.underline\" [matTooltip]=\"tooltip(config.tooltips.underline)\"></button>\n        <button class=\"ql-strike\"    *ngIf=\"config.buttons.strike\"    [matTooltip]=\"tooltip(config.tooltips.strike)\"></button>\n    </span>\n</ng-template>\n\n<ng-template #blockStyle>\n    <span class=\"ql-formats\" *ngIf=\"config.showBlockStyle\">\n        <button class=\"ql-blockquote\" *ngIf=\"config.buttons.blockquote\" [matTooltip]=\"tooltip(config.tooltips.blockquote)\"></button>\n        <button class=\"ql-code-block\" *ngIf=\"config.buttons.codeblock\"  [matTooltip]=\"tooltip(config.tooltips.codeblock)\"></button>\n    </span>\n</ng-template>\n\n<ng-template #headingStyle>\n    <span class=\"ql-formats\" *ngIf=\"config.showQuickHeadingStyle\">\n        <button class=\"ql-header\" value=\"1\" *ngIf=\"config.buttons.h1\" [matTooltip]=\"tooltip(config.tooltips.h1)\"></button>\n        <button class=\"ql-header\" value=\"2\" *ngIf=\"config.buttons.h2\" [matTooltip]=\"tooltip(config.tooltips.h2)\"></button>\n    </span>\n</ng-template>\n\n<ng-template #listStyle>\n    <span class=\"ql-formats\" *ngIf=\"config.showListStyle\">\n        <button class=\"ql-list\" value=\"ordered\" *ngIf=\"config.buttons.ordered\"  [matTooltip]=\"tooltip(config.tooltips.ordered)\"></button>\n        <button class=\"ql-list\" value=\"bullet\"  *ngIf=\"config.buttons.bulleted\" [matTooltip]=\"tooltip(config.tooltips.bulleted)\"></button>\n    </span>\n</ng-template>\n\n<ng-template #scriptStyle>\n    <span class=\"ql-formats\" *ngIf=\"config.showScriptStyle\">\n        <button class=\"ql-script\" value=\"sub\"   *ngIf=\"config.buttons.subScript\" [matTooltip]=\"tooltip(config.tooltips.subScript)\"></button>\n        <button class=\"ql-script\" value=\"super\" *ngIf=\"config.buttons.superScript\" [matTooltip]=\"tooltip(config.tooltips.superScript)\"></button>\n    </span>\n</ng-template>\n    \n<ng-template #indentStyle>\n    <span class=\"ql-formats\" *ngIf=\"config.showIndentStyle\">\n        <button class=\"ql-indent\" value=\"-1\" *ngIf=\"config.buttons.decreaseIndent\" [matTooltip]=\"tooltip(config.tooltips.decreaseIndent)\"></button>\n        <button class=\"ql-indent\" value=\"+1\" *ngIf=\"config.buttons.increaseIndent\" [matTooltip]=\"tooltip(config.tooltips.increaseIndent)\"></button>\n    </span>\n</ng-template>\n\n<ng-template #rtl>\n    <span class=\"ql-formats\" *ngIf=\"config.buttons.rtl\">\n        <button class=\"ql-direction\" value=\"rtl\" [matTooltip]=\"tooltip(config.tooltips.rtl)\"></button>\n    </span>\n</ng-template>\n\n<ng-template #fontSize>\n    <span class=\"ql-formats\" *ngIf=\"config.buttons.fontSize\" [matTooltip]=\"tooltip(config.tooltips.fontSize)\">\n        <select class=\"ql-size\">\n            <option value=\"small\"></option>\n            <option selected></option>\n            <option value=\"large\"></option>\n            <option value=\"huge\"></option>\n        </select>\n    </span>\n</ng-template>\n\n<ng-template #heading>\n    <span class=\"ql-formats\" *ngIf=\"config.buttons.headingStyle\" [matTooltip]=\"tooltip(config.tooltips.headingStyle)\">\n        <select class=\"ql-header\">\n            <option value=\"1\"></option>\n            <option value=\"2\"></option>\n            <option value=\"3\"></option>\n            <option value=\"4\"></option>\n            <option value=\"5\"></option>\n            <option value=\"6\"></option>\n            <option selected=\"selected\"></option>\n        </select>\n    </span>\n</ng-template>\n\n<ng-template #color>\n    <span class=\"ql-formats\" *ngIf=\"config.buttons.color\" [matTooltip]=\"tooltip(config.tooltips.color)\">\n        <select class=\"ql-color\"></select>\n        <select class=\"ql-background\"></select>\n    </span>\n</ng-template>\n\n<ng-template #font>\n    <span class=\"ql-formats\" *ngIf=\"config.buttons.font\" [matTooltip]=\"tooltip(config.tooltips.font)\">\n        <select class=\"ql-font\">\n            <option selected></option>\n            <option value=\"serif\"></option>\n            <option value=\"monospace\"></option>\n        </select>\n    </span>\n</ng-template>\n\n<ng-template #align>\n    <span class=\"ql-formats\" *ngIf=\"config.buttons.align\" [matTooltip]=\"tooltip(config.tooltips.align)\">\n        <select class=\"ql-align\">\n            <option selected></option>\n            <option value=\"center\"></option>\n            <option value=\"right\"></option>\n            <option value=\"justify\"></option>\n        </select>\n    </span>\n</ng-template>\n\n<ng-template #clean>\n    <span class=\"ql-formats\" *ngIf=\"config.buttons.clean\" [matTooltip]=\"tooltip(config.tooltips.clean)\">\n        <button class=\"ql-clean\"></button>\n    </span>\n</ng-template>\n\n<ng-template #media>\n    <span class=\"ql-formats\" *ngIf=\"config.showMedia\">\n        <button class=\"ql-link\"  *ngIf=\"config.buttons.link\" [matTooltip]=\"tooltip(config.tooltips.link)\"></button>\n        <button class=\"ql-image\" *ngIf=\"config.buttons.image\" [matTooltip]=\"tooltip(config.tooltips.image)\"></button>\n        <button class=\"ql-video\" *ngIf=\"config.buttons.video\" [matTooltip]=\"tooltip(config.tooltips.video)\"></button>\n    </span>\n</ng-template>\n\n<ng-template #editorSize>\n    <span class=\"ql-formats\" *ngIf=\"config.buttons.editorSize\">\n        <button id=\"fullscreen\"\n            [matTooltip]=\"tooltip(fullscreen ?\n                (fullscreenMode === 'expand' ? config.tooltips.minimize : config.tooltips.popin) :\n                (fullscreenMode === 'expand' ? config.tooltips.maximize : config.tooltips.popout))\">\n\n            <mat-icon (click)=\"toggleFullscreen()\">\n                {{ fullscreen ?\n                    (fullscreenMode === 'expand' ? config.icons.minimize : config.icons.popin) :\n                    (fullscreenMode === 'expand' ? config.icons.maximize : config.icons.popout)\n                }}\n            </mat-icon>\n        </button>\n    </span>\n</ng-template>\n\n<ng-template #formula>\n    <span class=\"ql-formats\" *ngIf=\"config.buttons.formula\" [matTooltip]=\"tooltip(config.tooltips.formula)\">\n        <button class=\"ql-formula\"></button>\n    </span>\n</ng-template>", styles: [".ql-toolbar{display:grid;grid-template-columns:1fr auto}mat-icon{color:#ff4500}quill-editor.readonly .ql-toolbar{opacity:.5}::ng-deep quill-editor.readonly .ql-container{background-color:#f5f5f5!important}\n"], dependencies: [{ kind: "directive", type: i3.NgIf, selector: "[ngIf]", inputs: ["ngIf", "ngIfThen", "ngIfElse"] }, { kind: "directive", type: i3.NgTemplateOutlet, selector: "[ngTemplateOutlet]", inputs: ["ngTemplateOutletContext", "ngTemplateOutlet", "ngTemplateOutletInjector"] }, { kind: "directive", type: i4.ɵNgNoValidate, selector: "form:not([ngNoForm]):not([ngNativeValidate])" }, { kind: "directive", type: i4.NgSelectOption, selector: "option", inputs: ["ngValue", "value"] }, { kind: "directive", type: i4.ɵNgSelectMultipleOption, selector: "option", inputs: ["ngValue", "value"] }, { kind: "directive", type: i4.NgControlStatus, selector: "[formControlName],[ngModel],[formControl]" }, { kind: "directive", type: i4.NgControlStatusGroup, selector: "[formGroupName],[formArrayName],[ngModelGroup],[formGroup],form:not([ngNoForm]),[ngForm]" }, { kind: "directive", type: i4.NgModel, selector: "[ngModel]:not([formControlName]):not([formControl])", inputs: ["name", "disabled", "ngModel", "ngModelOptions"], outputs: ["ngModelChange"], exportAs: ["ngModel"] }, { kind: "directive", type: i4.NgForm, selector: "form:not([ngNoForm]):not([formGroup]),ng-form,[ngForm]", inputs: ["ngFormOptions"], outputs: ["ngSubmit"], exportAs: ["ngForm"] }, { kind: "directive", type: i4.FormGroupDirective, selector: "[formGroup]", inputs: ["formGroup"], outputs: ["ngSubmit"], exportAs: ["ngForm"] }, { kind: "directive", type: i4.FormControlName, selector: "[formControlName]", inputs: ["formControlName", "disabled", "ngModel"], outputs: ["ngModelChange"] }, { kind: "component", type: i5.MatIcon, selector: "mat-icon", inputs: ["color", "inline", "svgIcon", "fontSet", "fontIcon"], exportAs: ["matIcon"] }, { kind: "directive", type: i6.MatTooltip, selector: "[matTooltip]", exportAs: ["matTooltip"] }, { kind: "component", type: i7.QuillEditorComponent, selector: "quill-editor" }] });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "14.2.1", ngImport: i0, type: EditorComponent, decorators: [{
            type: Component,
            args: [{ selector: 'cpquill-editor', template: "<ng-container *ngIf=\"users\">\n    <!-- Reactive forms -->\n    <form *ngIf=\"formGroup\" [formGroup]=\"formGroup\">\n        <quill-editor\n            [formControlName]=\"controlName\"\n            [placeholder]=\"placeholder\"\n            [format]=\"format\"\n            [style.height]=\"fullscreen ? maxHeight : height\"\n            [style.width]=\"fullscreen ? maxWidth : width\"\n            [readOnly]=\"readonly\"\n            [class.readonly]=\"readonly\"\n            [modules]=\"modules\"\n    \n            (onBlur)=\"onBlur.emit($event)\"\n            (onContentChanged)=\"onContentChanged.emit($event)\"\n            (onEditorChanged)=\"onEditorChanged.emit($event)\"\n            (onEditorCreated)=\"onEditorCreated.emit()\"\n            (onFocus)=\"onFocus.emit($event)\"\n            (onSelectionChanged)=\"onSelectionChanged.emit($event)\">\n    \n            <div quill-editor-toolbar>\n                <ng-container [ngTemplateOutlet]=\"toolbar\"></ng-container>\n                <ng-container [ngTemplateOutlet]=\"editorSize\"></ng-container>\n            </div>\n        </quill-editor>\n    </form>\n    \n    <!-- NgModel forms -->\n    <form *ngIf=\"!formGroup\">\n        <quill-editor name=\"editor\"\n            [(ngModel)]=\"ngModelValue\"\n            [placeholder]=\"placeholder\"\n            [format]=\"format\"\n            [style.height]=\"fullscreen ? maxHeight : height\"\n            [style.width]=\"fullscreen ? maxWidth : width\"\n            [readOnly]=\"readonly\"\n            [class.readonly]=\"readonly\"\n            [modules]=\"modules\"\n    \n            (onBlur)=\"onBlur.emit($event)\"\n            (onContentChanged)=\"onContentChanged.emit($event)\"\n            (onEditorChanged)=\"onEditorChanged.emit($event)\"\n            (onEditorCreated)=\"onEditorCreated.emit()\"\n            (onFocus)=\"onFocus.emit($event)\"\n            (onSelectionChanged)=\"onSelectionChanged.emit($event)\">\n    \n            <div quill-editor-toolbar>\n                <ng-container [ngTemplateOutlet]=\"toolbar\"></ng-container>\n                <ng-container [ngTemplateOutlet]=\"editorSize\"></ng-container>\n            </div>\n        </quill-editor>\n    </form>\n</ng-container>\n\n<ng-template #toolbar>\n    <div>\n        <ng-container [ngTemplateOutlet]=\"fontStyle\"></ng-container>\n        <ng-container [ngTemplateOutlet]=\"blockStyle\"></ng-container>\n        <ng-container [ngTemplateOutlet]=\"headingStyle\"></ng-container>\n        <ng-container [ngTemplateOutlet]=\"listStyle\"></ng-container>\n        <ng-container [ngTemplateOutlet]=\"scriptStyle\"></ng-container>\n        <ng-container [ngTemplateOutlet]=\"indentStyle\"></ng-container>\n        <ng-container [ngTemplateOutlet]=\"rtl\"></ng-container>\n        <ng-container [ngTemplateOutlet]=\"fontSize\"></ng-container>\n        <ng-container [ngTemplateOutlet]=\"heading\"></ng-container>\n        <ng-container [ngTemplateOutlet]=\"color\"></ng-container>\n        <ng-container [ngTemplateOutlet]=\"font\"></ng-container>\n        <ng-container [ngTemplateOutlet]=\"align\"></ng-container>\n        <ng-container [ngTemplateOutlet]=\"clean\"></ng-container>\n        <nt-container [ngTemplateOutlet]=\"formula\"></nt-container>\n        <ng-container [ngTemplateOutlet]=\"media\"></ng-container>\n    </div>\n</ng-template>\n\n<ng-template #fontStyle>\n    <span class=\"ql-formats\" *ngIf=\"config.showFontStyle\">\n        <button class=\"ql-bold\"      *ngIf=\"config.buttons.bold\"      [matTooltip]=\"tooltip(config.tooltips.bold)\"></button>\n        <button class=\"ql-italic\"    *ngIf=\"config.buttons.italic\"    [matTooltip]=\"tooltip(config.tooltips.italic)\"></button>\n        <button class=\"ql-underline\" *ngIf=\"config.buttons.underline\" [matTooltip]=\"tooltip(config.tooltips.underline)\"></button>\n        <button class=\"ql-strike\"    *ngIf=\"config.buttons.strike\"    [matTooltip]=\"tooltip(config.tooltips.strike)\"></button>\n    </span>\n</ng-template>\n\n<ng-template #blockStyle>\n    <span class=\"ql-formats\" *ngIf=\"config.showBlockStyle\">\n        <button class=\"ql-blockquote\" *ngIf=\"config.buttons.blockquote\" [matTooltip]=\"tooltip(config.tooltips.blockquote)\"></button>\n        <button class=\"ql-code-block\" *ngIf=\"config.buttons.codeblock\"  [matTooltip]=\"tooltip(config.tooltips.codeblock)\"></button>\n    </span>\n</ng-template>\n\n<ng-template #headingStyle>\n    <span class=\"ql-formats\" *ngIf=\"config.showQuickHeadingStyle\">\n        <button class=\"ql-header\" value=\"1\" *ngIf=\"config.buttons.h1\" [matTooltip]=\"tooltip(config.tooltips.h1)\"></button>\n        <button class=\"ql-header\" value=\"2\" *ngIf=\"config.buttons.h2\" [matTooltip]=\"tooltip(config.tooltips.h2)\"></button>\n    </span>\n</ng-template>\n\n<ng-template #listStyle>\n    <span class=\"ql-formats\" *ngIf=\"config.showListStyle\">\n        <button class=\"ql-list\" value=\"ordered\" *ngIf=\"config.buttons.ordered\"  [matTooltip]=\"tooltip(config.tooltips.ordered)\"></button>\n        <button class=\"ql-list\" value=\"bullet\"  *ngIf=\"config.buttons.bulleted\" [matTooltip]=\"tooltip(config.tooltips.bulleted)\"></button>\n    </span>\n</ng-template>\n\n<ng-template #scriptStyle>\n    <span class=\"ql-formats\" *ngIf=\"config.showScriptStyle\">\n        <button class=\"ql-script\" value=\"sub\"   *ngIf=\"config.buttons.subScript\" [matTooltip]=\"tooltip(config.tooltips.subScript)\"></button>\n        <button class=\"ql-script\" value=\"super\" *ngIf=\"config.buttons.superScript\" [matTooltip]=\"tooltip(config.tooltips.superScript)\"></button>\n    </span>\n</ng-template>\n    \n<ng-template #indentStyle>\n    <span class=\"ql-formats\" *ngIf=\"config.showIndentStyle\">\n        <button class=\"ql-indent\" value=\"-1\" *ngIf=\"config.buttons.decreaseIndent\" [matTooltip]=\"tooltip(config.tooltips.decreaseIndent)\"></button>\n        <button class=\"ql-indent\" value=\"+1\" *ngIf=\"config.buttons.increaseIndent\" [matTooltip]=\"tooltip(config.tooltips.increaseIndent)\"></button>\n    </span>\n</ng-template>\n\n<ng-template #rtl>\n    <span class=\"ql-formats\" *ngIf=\"config.buttons.rtl\">\n        <button class=\"ql-direction\" value=\"rtl\" [matTooltip]=\"tooltip(config.tooltips.rtl)\"></button>\n    </span>\n</ng-template>\n\n<ng-template #fontSize>\n    <span class=\"ql-formats\" *ngIf=\"config.buttons.fontSize\" [matTooltip]=\"tooltip(config.tooltips.fontSize)\">\n        <select class=\"ql-size\">\n            <option value=\"small\"></option>\n            <option selected></option>\n            <option value=\"large\"></option>\n            <option value=\"huge\"></option>\n        </select>\n    </span>\n</ng-template>\n\n<ng-template #heading>\n    <span class=\"ql-formats\" *ngIf=\"config.buttons.headingStyle\" [matTooltip]=\"tooltip(config.tooltips.headingStyle)\">\n        <select class=\"ql-header\">\n            <option value=\"1\"></option>\n            <option value=\"2\"></option>\n            <option value=\"3\"></option>\n            <option value=\"4\"></option>\n            <option value=\"5\"></option>\n            <option value=\"6\"></option>\n            <option selected=\"selected\"></option>\n        </select>\n    </span>\n</ng-template>\n\n<ng-template #color>\n    <span class=\"ql-formats\" *ngIf=\"config.buttons.color\" [matTooltip]=\"tooltip(config.tooltips.color)\">\n        <select class=\"ql-color\"></select>\n        <select class=\"ql-background\"></select>\n    </span>\n</ng-template>\n\n<ng-template #font>\n    <span class=\"ql-formats\" *ngIf=\"config.buttons.font\" [matTooltip]=\"tooltip(config.tooltips.font)\">\n        <select class=\"ql-font\">\n            <option selected></option>\n            <option value=\"serif\"></option>\n            <option value=\"monospace\"></option>\n        </select>\n    </span>\n</ng-template>\n\n<ng-template #align>\n    <span class=\"ql-formats\" *ngIf=\"config.buttons.align\" [matTooltip]=\"tooltip(config.tooltips.align)\">\n        <select class=\"ql-align\">\n            <option selected></option>\n            <option value=\"center\"></option>\n            <option value=\"right\"></option>\n            <option value=\"justify\"></option>\n        </select>\n    </span>\n</ng-template>\n\n<ng-template #clean>\n    <span class=\"ql-formats\" *ngIf=\"config.buttons.clean\" [matTooltip]=\"tooltip(config.tooltips.clean)\">\n        <button class=\"ql-clean\"></button>\n    </span>\n</ng-template>\n\n<ng-template #media>\n    <span class=\"ql-formats\" *ngIf=\"config.showMedia\">\n        <button class=\"ql-link\"  *ngIf=\"config.buttons.link\" [matTooltip]=\"tooltip(config.tooltips.link)\"></button>\n        <button class=\"ql-image\" *ngIf=\"config.buttons.image\" [matTooltip]=\"tooltip(config.tooltips.image)\"></button>\n        <button class=\"ql-video\" *ngIf=\"config.buttons.video\" [matTooltip]=\"tooltip(config.tooltips.video)\"></button>\n    </span>\n</ng-template>\n\n<ng-template #editorSize>\n    <span class=\"ql-formats\" *ngIf=\"config.buttons.editorSize\">\n        <button id=\"fullscreen\"\n            [matTooltip]=\"tooltip(fullscreen ?\n                (fullscreenMode === 'expand' ? config.tooltips.minimize : config.tooltips.popin) :\n                (fullscreenMode === 'expand' ? config.tooltips.maximize : config.tooltips.popout))\">\n\n            <mat-icon (click)=\"toggleFullscreen()\">\n                {{ fullscreen ?\n                    (fullscreenMode === 'expand' ? config.icons.minimize : config.icons.popin) :\n                    (fullscreenMode === 'expand' ? config.icons.maximize : config.icons.popout)\n                }}\n            </mat-icon>\n        </button>\n    </span>\n</ng-template>\n\n<ng-template #formula>\n    <span class=\"ql-formats\" *ngIf=\"config.buttons.formula\" [matTooltip]=\"tooltip(config.tooltips.formula)\">\n        <button class=\"ql-formula\"></button>\n    </span>\n</ng-template>", styles: [".ql-toolbar{display:grid;grid-template-columns:1fr auto}mat-icon{color:#ff4500}quill-editor.readonly .ql-toolbar{opacity:.5}::ng-deep quill-editor.readonly .ql-container{background-color:#f5f5f5!important}\n"] }]
        }], ctorParameters: function () { return [{ type: undefined, decorators: [{
                    type: Optional
                }, {
                    type: Inject,
                    args: [MAT_DIALOG_DATA]
                }] }, { type: i1.MatDialogRef, decorators: [{
                    type: Optional
                }] }, { type: i2.ActiveDirectoryService }, { type: i1.MatDialog }]; }, propDecorators: { editor: [{
                type: ViewChild,
                args: [QuillEditorComponent, { static: false }]
            }], formGroup: [{
                type: Input
            }], controlName: [{
                type: Input
            }], ngModelValue: [{
                type: Input
            }], config: [{
                type: Input
            }], placeholder: [{
                type: Input
            }], users: [{
                type: Input
            }], format: [{
                type: Input
            }], height: [{
                type: Input
            }], width: [{
                type: Input
            }], maxHeight: [{
                type: Input
            }], maxWidth: [{
                type: Input
            }], enableTooltips: [{
                type: Input
            }], fullscreen: [{
                type: Input
            }], fullscreenMode: [{
                type: Input
            }], readonly: [{
                type: Input
            }], imageResizeModule: [{
                type: Input
            }], imageDropModule: [{
                type: Input
            }], mentionModule: [{
                type: Input
            }], syntaxModule: [{
                type: Input
            }], fullscreenChanged: [{
                type: Output
            }], onBlur: [{
                type: Output
            }], onContentChanged: [{
                type: Output
            }], onEditorChanged: [{
                type: Output
            }], onEditorCreated: [{
                type: Output
            }], onFocus: [{
                type: Output
            }], onSelectionChanged: [{
                type: Output
            }] } });

class QuillEditorModule {
    constructor(parentModule) {
        if (parentModule) {
            throw new Error('QuillEditorModule is already loaded. Import it in the AppModule only');
        }
    }
    static forRoot() {
        return {
            ngModule: QuillEditorModule
        };
    }
}
QuillEditorModule.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "14.2.1", ngImport: i0, type: QuillEditorModule, deps: [{ token: QuillEditorModule, optional: true, skipSelf: true }], target: i0.ɵɵFactoryTarget.NgModule });
QuillEditorModule.ɵmod = i0.ɵɵngDeclareNgModule({ minVersion: "14.0.0", version: "14.2.1", ngImport: i0, type: QuillEditorModule, declarations: [EditorComponent], imports: [CommonModule,
        FormsModule,
        ReactiveFormsModule,
        MatButtonModule,
        MatDialogModule,
        MatIconModule,
        MatTooltipModule, i7.QuillModule], exports: [EditorComponent] });
QuillEditorModule.ɵinj = i0.ɵɵngDeclareInjector({ minVersion: "12.0.0", version: "14.2.1", ngImport: i0, type: QuillEditorModule, imports: [CommonModule,
        FormsModule,
        ReactiveFormsModule,
        MatButtonModule,
        MatDialogModule,
        MatIconModule,
        MatTooltipModule,
        QuillModule.forRoot()] });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "14.2.1", ngImport: i0, type: QuillEditorModule, decorators: [{
            type: NgModule,
            args: [{
                    declarations: [
                        EditorComponent
                    ],
                    imports: [
                        CommonModule,
                        FormsModule,
                        ReactiveFormsModule,
                        MatButtonModule,
                        MatDialogModule,
                        MatIconModule,
                        MatTooltipModule,
                        QuillModule.forRoot()
                    ],
                    exports: [
                        EditorComponent
                    ]
                }]
        }], ctorParameters: function () { return [{ type: QuillEditorModule, decorators: [{
                    type: Optional
                }, {
                    type: SkipSelf
                }] }]; } });

/**
 * Generated bundle index. Do not edit.
 */

export { Buttons, Config, EditorComponent, Icons, QuillEditorModule, Tooltips };
//# sourceMappingURL=cleavelandprice-ngx-lib-quill-editor.mjs.map
